@@ -1,11 +1,13 @@
 """Base utilities for commonmeta-py"""
 
+from __future__ import annotations
+
 import html
 import re
 import uuid
 from datetime import datetime
 from os import path
-from typing import Any, Dict, Iterable, List, Optional, TypeVar, Union
+from typing import Any, Generator, Iterable, TypeVar
 
 import nh3
 import xmltodict
@@ -13,7 +15,7 @@ import xmltodict
 T = TypeVar("T")
 
 
-def _tokens(path: Union[str, Iterable[Any]]):
+def _tokens(path: str | Iterable[Any]) -> Generator[str | int, None, None]:
     """Yield tokens from a dot/bracket path like a.b[0]['c'] or a.0.b"""
     if isinstance(path, (list, tuple)):
         yield from path
@@ -73,7 +75,7 @@ def _tokens(path: Union[str, Iterable[Any]]):
             yield token
 
 
-def dig(obj: Any, path: Union[str, Iterable[Any]], default: Any = None) -> Any:
+def dig(obj: Any, path: str | Iterable[Any], default: Any = None) -> Any:
     """
     Safe nested getter similar to pydash.get.
     """
@@ -85,13 +87,15 @@ def dig(obj: Any, path: Union[str, Iterable[Any]], default: Any = None) -> Any:
             elif isinstance(cur, (list, tuple)) and isinstance(key, int):
                 cur = cur[key]
             else:
-                cur = getattr(cur, key)
+                # getattr expects a string attribute name
+                key_str = str(key) if not isinstance(key, str) else key
+                cur = getattr(cur, key_str)
         except (KeyError, IndexError, AttributeError, TypeError):
             return default
     return cur
 
 
-def unique(iterable: Optional[Iterable[T]]) -> List[T]:
+def unique(iterable: Iterable[T] | None) -> list[T]:
     """
     Return a list of unique values in the given iterable, preserving order.
     Returns empty list if iterable is None.
@@ -107,7 +111,7 @@ def unique(iterable: Optional[Iterable[T]]) -> List[T]:
     return result
 
 
-def omit(obj: Optional[Dict[str, Any]], *keys) -> Dict[str, Any]:
+def omit(obj: dict[str, Any] | None, *keys) -> dict[str, Any]:
     """
     Return a new dict without the specified keys.
     Can accept keys as separate arguments or as an iterable.
@@ -124,7 +128,7 @@ def omit(obj: Optional[Dict[str, Any]], *keys) -> Dict[str, Any]:
     return {k: v for k, v in obj.items() if k not in keys}
 
 
-def keep(obj: Optional[Dict[str, Any]], keys: Iterable[str]) -> Dict[str, Any]:
+def keep(obj: dict[str, Any] | None, keys: Iterable[str]) -> dict[str, Any]:
     """
     Return a new dict with only the specified keys.
     Returns empty dict if obj is None.
@@ -136,7 +140,7 @@ def keep(obj: Optional[Dict[str, Any]], keys: Iterable[str]) -> Dict[str, Any]:
     return {k: v for k, v in obj.items() if k in keys}
 
 
-def wrap(item: Optional[Union[dict, list, str]]) -> list:
+def wrap(item: dict | list | str | None) -> list:
     """Turn None, dict, or list into list"""
     if item is None:
         return []
@@ -145,7 +149,7 @@ def wrap(item: Optional[Union[dict, list, str]]) -> list:
     return [item]
 
 
-def unwrap(lst: list) -> Optional[Union[dict, list]]:
+def unwrap(lst: list) -> dict | list | None:
     """Turn list into dict or None, depending on list size"""
     if len(lst) == 0:
         return None
@@ -154,7 +158,14 @@ def unwrap(lst: list) -> Optional[Union[dict, list]]:
     return lst
 
 
-def flatten(array: Iterable[Iterable[Any]]) -> List[Any]:
+def first(lst: list | None) -> Any:
+    """Return the first element of a list or None if the list is empty or None."""
+    if lst is not None and len(lst) > 0:
+        return lst[0]
+    return None
+
+
+def flatten(array: Iterable[Iterable[Any]]) -> list:
     """
     Flatten a list one level deep.
     """
@@ -168,24 +179,28 @@ def flatten(array: Iterable[Iterable[Any]]) -> List[Any]:
 
 
 def presence(
-    item: Optional[Union[dict, list, str]],
-) -> Optional[Union[dict, list, str]]:
+    item: dict | list | str | None,
+) -> dict | list | str | None:
     """Turn empty list, dict or str into None"""
     return None if item is None or len(item) == 0 or item == [{}] else item
 
 
-def compact(dict_or_list: Union[dict, list]) -> Optional[Union[dict, list]]:
-    """Remove None from dict or list"""
-    if isinstance(dict_or_list, dict):
-        return {k: v for k, v in dict_or_list.items() if v is not None}
-    if isinstance(dict_or_list, list):
-        lst = [compact(i) for i in dict_or_list]
-        return lst if len(lst) > 0 else None
-
-    return None
+def compact(obj: dict | None) -> dict:
+    """Remove None values from dict"""
+    if obj is None:
+        return {}
+    return {k: v for k, v in obj.items() if v is not None}
 
 
-def _split_words(s: str) -> List[str]:
+def scrub(list_obj: Iterable[dict] | None) -> list | None:
+    """Remove None values from list recursively"""
+    if list_obj is None:
+        return None
+    lst = [compact(i) for i in list_obj]
+    return lst if len(lst) > 0 else None
+
+
+def _split_words(s: str) -> list[str]:
     """Split string into words by space, underscore, hyphen, and case changes."""
     words, current = [], []
     for i, ch in enumerate(s):
@@ -226,34 +241,55 @@ def kebab_case(s: str) -> str:
     return "-".join(w.lower() for w in words if w)
 
 
-def parse_attributes(
-    element: Union[str, dict, list], **kwargs
-) -> Optional[Union[str, list]]:
-    """extract attributes from a string, dict or list"""
+def parse_attributes(element: str | dict | list | None, **kwargs) -> list[str]:
+    """Extract attributes from a string, dict or list.
 
-    def parse_item(item):
+    Args:
+        element: Input to parse (str, dict, list, or None)
+        **kwargs: Optional parameters:
+            - content: Key to extract from dict (default: "#text")
+
+    Returns:
+        - list of extracted strings, or empty list if none found
+    """
+
+    def parse_item(item) -> str | None:
+        """Parse a single item from the element list"""
         if isinstance(item, dict):
             return item.get(html.unescape(content), None)
-        return html.unescape(item)
+        return html.unescape(item) if isinstance(item, str) else None
+
+    if element is None:
+        return []
 
     content = kwargs.get("content", "#text")
     if isinstance(element, str) and kwargs.get("content", None) is None:
-        return html.unescape(element)
+        return [html.unescape(element)]
     if isinstance(element, dict):
-        return element.get(html.unescape(content), None)
+        value = element.get(html.unescape(content), None)
+        return [value] if value is not None else []
     if isinstance(element, list):
         arr = [parse_item(i) for i in element if i]
-        arr = arr[0] if len(arr) > 0 and kwargs.get("first") else unwrap(arr)
+        # Filter out None values
+        arr = [item for item in arr if item is not None]
+        arr = [arr[0]] if len(arr) > 0 and kwargs.get("first") else arr
         return arr
 
+    return []
 
-def parse_xml(string: Optional[str], **kwargs) -> Optional[Union[dict, list]]:
+
+def parse_xml(string: str | bytes | None, **kwargs) -> dict | list | None:
     """Parse XML into dict using xmltodict. Set default options, and options for Crossref XML"""
     if string is None or string == "{}":
         return None
-    if path.exists(string):
+
+    # Convert to string if it's a file path
+    xml_string: str | bytes
+    if isinstance(string, (str, bytes)) and path.exists(string):
         with open(string, encoding="utf-8") as file:
-            string = file.read()
+            xml_string = file.read()
+    else:
+        xml_string = string
 
     if kwargs.get("dialect", None) == "crossref":
         # remove namespaces from xml
@@ -284,33 +320,33 @@ def parse_xml(string: Optional[str], **kwargs) -> Optional[Union[dict, list]]:
     kwargs["attr_prefix"] = ""
     kwargs["dict_constructor"] = dict
     kwargs.pop("dialect", None)
-    return xmltodict.parse(string, **kwargs)
+    return xmltodict.parse(xml_string, **kwargs)
 
 
-def unparse_xml(input: Optional[dict], **kwargs) -> str:
+def unparse_xml(input: dict | None, **kwargs) -> bytes | None:
     """Unparse (dump) dict into XML using xmltodict. Set default options, and options for Crossref XML"""
     if input is None:
         return None
     if kwargs.get("dialect", None) == "crossref":
         # Add additional logic for crossref dialect
         # add body and root element as wrapping elements
-        type = next(iter(input))
-        attributes = input.get(type)
-        input.pop(type)
+        item_type = next(iter(input))
+        attributes = input.get(item_type) or {}
+        input.pop(item_type)
 
-        if type == "book":
+        if item_type == "book":
             book_metadata = dig(input, "book_metadata") or {}
             input.pop("book_metadata")
             book_metadata = {**book_metadata, **input}
             input = {"book": {**attributes, "book_metadata": book_metadata}}
-        elif type == "database":
+        elif item_type == "database":
             database_metadata = dig(input, "database_metadata") or {}
             input.pop("database_metadata")
             val = input.pop("publisher_item")
             institution = input.pop("institution", None)
             database_metadata = {**{"titles": val}, **database_metadata}
             database_metadata["institution"] = institution or {}
-            component = input.pop("component", None)
+            component = input.pop("component", None) or {}
             input = {
                 "database": {
                     **attributes,
@@ -318,7 +354,7 @@ def unparse_xml(input: Optional[dict], **kwargs) -> str:
                     "component_list": {"component": component | input},
                 }
             }
-        elif type == "journal":
+        elif item_type == "journal":
             journal_metadata = dig(input, "journal_metadata") or {}
             journal_issue = dig(input, "journal_issue") or {}
             journal_article = dig(input, "journal_article") or {}
@@ -332,7 +368,7 @@ def unparse_xml(input: Optional[dict], **kwargs) -> str:
                     "journal_article": journal_article | input,
                 }
             }
-        elif type == "proceedings_article":
+        elif item_type == "proceedings_article":
             proceedings_metadata = dig(input, "proceedings_metadata") or {}
             input.pop("proceedings_metadata")
             input = {
@@ -342,7 +378,7 @@ def unparse_xml(input: Optional[dict], **kwargs) -> str:
                     "conference_paper": input,
                 }
             }
-        elif type == "sa_component":
+        elif item_type == "sa_component":
             component = dig(input, "component") or {}
             input.pop("component")
             input = {
@@ -352,9 +388,9 @@ def unparse_xml(input: Optional[dict], **kwargs) -> str:
                 }
             }
         else:
-            input = {type: attributes | input}
+            input = {item_type: attributes | input}
 
-        head = kwargs["head"] or {}
+        head = kwargs.get("head", {}) or {}
         doi_batch = {
             "@xmlns": "http://www.crossref.org/schema/5.4.0",
             "@xmlns:ai": "http://www.crossref.org/AccessIndicators.xsd",
@@ -364,17 +400,17 @@ def unparse_xml(input: Optional[dict], **kwargs) -> str:
             "head": get_crossref_xml_head(head),
             "body": input,
         }
-        output = {"doi_batch": doi_batch}
+        output: dict[str, Any] = {"doi_batch": doi_batch}
     else:
-        output = input
+        output: dict[str, Any] = input
     kwargs["pretty"] = True
     kwargs["indent"] = "  "
     kwargs.pop("dialect", None)
     kwargs.pop("head", None)
-    return xmltodict.unparse(output, **kwargs)
+    return xmltodict.unparse(output, **kwargs).encode("utf-8")
 
 
-def unparse_xml_list(input: Optional[list], **kwargs) -> str:
+def unparse_xml_list(input: list | None, **kwargs) -> bytes | None:
     """Unparse (dump) list into XML using xmltodict. Set default options, and options for Crossref XML"""
     if input is None:
         return None
@@ -383,27 +419,27 @@ def unparse_xml_list(input: Optional[list], **kwargs) -> str:
         # add body and root element as wrapping elements
 
         # Group items by type with minimal grouping
-        items_by_type = {}
+        items_by_type: dict[str, list] = {}
 
         for item in wrap(input):
-            type = next(iter(item))
-            attributes = item.get(type)
-            item.pop(type)
+            item_type = next(iter(item))
+            attributes = item.get(item_type) or {}
+            item.pop(item_type)
 
             # handle nested book_metadata and journal structure as in unparse_xml
-            if type == "book":
+            if item_type == "book":
                 book_metadata = dig(item, "book_metadata") or {}
                 item.pop("book_metadata")
                 book_metadata = {**book_metadata, **item}
                 item = {"book": {**attributes, "book_metadata": book_metadata}}
-            elif type == "database":
+            elif item_type == "database":
                 database_metadata = dig(item, "database_metadata") or {}
                 item.pop("database_metadata")
                 database_metadata = {**database_metadata, **item}
                 item = {
                     "database": {**attributes, "database_metadata": database_metadata}
                 }
-            elif type == "journal":
+            elif item_type == "journal":
                 journal_metadata = dig(item, "journal_metadata") or {}
                 journal_issue = dig(item, "journal_issue") or {}
                 journal_article = dig(item, "journal_article") or {}
@@ -417,8 +453,8 @@ def unparse_xml_list(input: Optional[list], **kwargs) -> str:
                         "journal_article": journal_article | item,
                     }
                 }
-            elif type == "sa_component":
-                component = dig(input, "component") or {}
+            elif item_type == "sa_component":
+                component = dig(item, "component") or {}
                 item.pop("component")
                 item = {
                     "sa_component": {
@@ -427,21 +463,21 @@ def unparse_xml_list(input: Optional[list], **kwargs) -> str:
                     }
                 }
             else:
-                item = {type: attributes | item}
+                item = {item_type: attributes | item}
 
             # Add item to appropriate type bucket
-            if type not in items_by_type:
-                items_by_type[type] = []
-            items_by_type[type].append(item[type])
+            if item_type not in items_by_type:
+                items_by_type[item_type] = []
+            items_by_type[item_type].append(item[item_type])
 
         # Create the final structure with body containing all grouped items
-        body_content = {}
+        body_content: dict[str, Any] = {}
         for type_key, items in items_by_type.items():
             if len(items) == 1:
                 body_content[type_key] = items[0]  # Use single item without array
             else:
                 body_content[type_key] = items  # Use array when multiple items
-        head = kwargs["head"] or {}
+        head = kwargs.get("head", {}) or {}
         doi_batch = {
             "@xmlns": "http://www.crossref.org/schema/5.4.0",
             "@xmlns:ai": "http://www.crossref.org/AccessIndicators.xsd",
@@ -452,12 +488,14 @@ def unparse_xml_list(input: Optional[list], **kwargs) -> str:
             "body": body_content,
         }
         output = {"doi_batch": doi_batch}
+    else:
+        output = {"body": input}
 
     kwargs["pretty"] = True
     kwargs["indent"] = "  "
     kwargs.pop("dialect", None)
     kwargs.pop("head", None)
-    return xmltodict.unparse(output, **kwargs)
+    return xmltodict.unparse(output, **kwargs).encode("utf-8")
 
 
 def get_crossref_xml_head(metadata: dict) -> dict:
