@@ -611,6 +611,124 @@ DATACITE_CONTRIBUTOR_TYPES = {
     "WorkPackageLeader": "WorkPackageLeader",
 }
 
+DC_TO_CM_CONTRIBUTOR_ROLES = {
+    "ContactPerson": "ContactPerson",
+    "DataCollector": "DataCollector",
+    "DataCurator": "DataCuration",
+    "DataManager": "DataManager",
+    "Distributor": "Distributor",
+    "Editor": "Editor",
+    "HostingInstitution": "HostingInstitution",
+    "Other": "Other",
+    "Producer": "Producer",
+    "ProjectLeader": "ProjectLeader",
+    "ProjectManager": "ProjectManager",
+    "ProjectMember": "ProjectMember",
+    "RegistrationAgency": "RegistrationAgency",
+    "RegistrationAuthority": "RegistrationAuthority",
+    "RelatedPerson": "RelatedPerson",
+    "ResearchGroup": "ResearchGroup",
+    "RightsHolder": "RightsHolder",
+    "Researcher": "Researcher",
+    "Sponsor": "Sponsor",
+    "Supervision": "Supervisor",
+    "WorkPackageLeader": "WorkPackageLeader",
+}
+
+CM_TO_DC_CONTRIBUTOR_ROLES = {
+    "ContactPerson": "ContactPerson",
+    "DataCollector": "DataCollector",
+    "DataCurator": "DataCuration",
+    "DataManager": "DataManager",
+    "Distributor": "Distributor",
+    "Editor": "Editor",
+    "HostingInstitution": "HostingInstitution",
+    "Other": "Other",
+    "Producer": "Producer",
+    "ProjectLeader": "ProjectLeader",
+    "ProjectManager": "ProjectManager",
+    "ProjectMember": "ProjectMember",
+    "RegistrationAgency": "RegistrationAgency",
+    "RegistrationAuthority": "RegistrationAuthority",
+    "RelatedPerson": "RelatedPerson",
+    "ResearchGroup": "ResearchGroup",
+    "RightsHolder": "RightsHolder",
+    "Researcher": "Researcher",
+    "Sponsor": "Sponsor",
+    "Supervisor": "Supervision",
+    "WorkPackageLeader": "WorkPackageLeader",
+}
+
+INVENIORDM_TO_CM_CONTRIBUTOR_ROLES = {
+    "contactperson": "ContactPerson",
+    "datacollector": "DataCollector",
+    "datacurator": "DataCuration",
+    "datamanager": "DataManager",
+    "distributor": "Distributor",
+    "editor": "Editor",
+    "hostinginstitution": "HostingInstitution",
+    "interviewee": "Interviewee",
+    "other": "Other",
+    "producer": "Producer",
+    "projectleader": "ProjectLeader",
+    "projectmanager": "ProjectManager",
+    "projectmember": "ProjectMember",
+    "registrationagency": "RegistrationAgency",
+    "registrationauthority": "RegistrationAuthority",
+    "relatedperson": "RelatedPerson",
+    "researchgroup": "ResearchGroup",
+    "rightsholder": "RightsHolder",
+    "researcher": "Researcher",
+    "sponsor": "Sponsor",
+    "supervisor": "Supervision",
+    "translator": "Translator",
+    "workpackageleader": "WorkPackageLeader",
+}
+
+CM_TO_INVENIORDM_CONTRIBUTOR_ROLES = {
+    "ContactPerson": "contactperson",
+    "DataCollector": "datacollector",
+    "DataCuration": "datacurator",
+    "DataManager": "datamanager",
+    "Distributor": "distributor",
+    "Editor": "editor",
+    "HostingInstitution": "hostinginstitution",
+    "Interviewee": "interviewee",
+    "Other": "other",
+    "Producer": "producer",
+    "ProjectLeader": "projectleader",
+    "ProjectManager": "projectmanager",
+    "ProjectMember": "projectmember",
+    "RegistrationAgency": "registrationagency",
+    "RegistrationAuthority": "registrationauthority",
+    "RelatedPerson": "relatedperson",
+    "ResearchGroup": "researchgroup",
+    "RightsHolder": "rightsholder",
+    "Researcher": "researcher",
+    "Sponsor": "sponsor",
+    "Supervision": "supervisor",
+    "Translator": "translator",
+    "WorkPackageLeader": "workpackageleader",
+}
+
+CR_TO_CM_CONTRIBUTOR_ROLES = {
+    "author": "Author",
+    "editor": "Editor",
+    "chair": "Chair",
+    "reviewer": "Reviewer",
+    "reader": "Reader",
+    "translator": "Translator",
+}
+
+CM_TO_CR_CONTRIBUTOR_ROLES = {
+    "Author": "author",
+    "Editor": "editor",
+    "Chair": "chair",
+    "Reviewer": "reviewer",
+    "Reader": "reader",
+    "Translator": "translator",
+}
+
 # from commonmeta schema
 COMMONMETA_RELATION_TYPES = [
     "IsNewVersionOf",
@@ -633,47 +751,48 @@ COMMONMETA_RELATION_TYPES = [
 # from commonmeta schema
 COMMONMETA_CONTRIBUTOR_ROLES = [
     "Author",
-    "Editor",
     "Chair",
-    "Reviewer",
-    "ReviewAssistant",
-    "StatsReviewer",
-    "ReviewerExternal",
-    "Reader",
-    "Translator",
+    "Conceptualization",
     "ContactPerson",
     "DataCollector",
+    "DataCuration",
     "DataManager",
     "Distributor",
+    "Editor",
+    "FormalAnalysis",
+    "FundingAcquisition",
     "HostingInstitution",
+    "Interviewee",
+    "Investigation",
+    "Maintainer",
+    "Methodology",
+    "Other",
     "Producer",
+    "ProjectAdministration",
     "ProjectLeader",
     "ProjectManager",
     "ProjectMember",
+    "Reader",
     "RegistrationAgency",
     "RegistrationAuthority",
     "RelatedPerson",
     "ResearchGroup",
-    "RightsHolder",
     "Researcher",
-    "Sponsor",
-    "WorkPackageLeader",
-    "Conceptualization",
-    "DataCuration",
-    "FormalAnalysis",
-    "FundingAcquisition",
-    "Investigation",
-    "Methodology",
-    "ProjectAdministration",
     "Resources",
+    "Reviewer",
+    "ReviewerExternal",
+    "ReviewAssistant",
+    "RightsHolder",
     "Software",
+    "Sponsor",
+    "StatsReviewer",
     "Supervision",
+    "Translator",
     "Validation",
     "Visualization",
+    "WorkPackageLeader",
     "WritingOriginalDraft",
     "WritingReviewEditing",
-    "Maintainer",
-    "Other",
 ]
 
 INVENIORDM_IDENTIFIER_TYPES = {
