@@ -1,16 +1,19 @@
 """CSL-JSON reader for commonmeta-py"""
-from ..utils import dict_to_spdx, from_csl, normalize_id, name_to_fos, issn_as_url
-from ..base_utils import wrap, compact, sanitize, presence
+
+from __future__ import annotations
+
 from ..author_utils import get_authors
-from ..date_utils import get_date_from_date_parts
-from ..doi_utils import get_doi_ra, doi_from_url, encode_doi
+from ..base_utils import compact, presence, sanitize, wrap
 from ..constants import (
     CSL_TO_CM_TRANSLATIONS,
     Commonmeta,
 )
+from ..date_utils import get_date_from_date_parts
+from ..doi_utils import doi_from_url, encode_doi, get_doi_ra
+from ..utils import dict_to_spdx, from_csl, issn_as_url, name_to_fos, normalize_id
 
 
-def read_csl(data: dict, **kwargs) -> Commonmeta:
+def read_csl(data: dict | None, **kwargs) -> Commonmeta:
     """read_csl"""
     if data is None:
         return {"state": "not_found"}
@@ -18,7 +21,9 @@ def read_csl(data: dict, **kwargs) -> Commonmeta:
 
     read_options = kwargs or {}
 
-    _id = normalize_id(meta.get("id", None) or meta.get("DOI", None)) or meta.get("id", None)
+    _id = normalize_id(meta.get("id", None) or meta.get("DOI", None)) or meta.get(
+        "id", None
+    )
     _type = CSL_TO_CM_TRANSLATIONS.get(meta.get("type", None), "Other")
 
     # optionally generate a DOI if missing but a DOI prefix is provided
