@@ -26,6 +26,7 @@ from ..base_utils import (
     unparse_xml_list,
     wrap,
 )
+from ..constants import CM_TO_CR_CONTRIBUTOR_ROLES
 from ..doi_utils import doi_from_url, is_rogue_scholar_doi, validate_doi
 from ..utils import validate_url
 from .inveniordm_writer import push_inveniordm, update_legacy_record
@@ -123,7 +124,7 @@ def convert_crossref_xml(metadata: Metadata) -> dict | None:
         "Standard",
     ]:
         raise CrossrefError(
-            f"Type {metadata.type} not supported by Crossref: {metadata.id}"
+            f"Type not supported by Crossref: {metadata.type} for {metadata.id}"
         )
 
     # raise error if doi or url are not present
@@ -378,6 +379,10 @@ def write_crossref_xml(metadata: Metadata) -> bytes | None:
     # Convert metadata to Crossref XML structure (raises CrossrefError on failure)
     data = convert_crossref_xml(metadata)
 
+    # Check for existing validation errors early
+    if metadata.write_errors is not None:
+        raise CrossrefError(f"Validation errors in metadata: {metadata.write_errors}")
+
     # Use the marshmallow schema to dump the data
     schema = CrossrefXMLSchema()
     crossref_xml = schema.dump(data)
@@ -706,11 +711,11 @@ def get_contributors(obj) -> dict | None:
     if len(wrap(dig(obj, "contributors"))) == 0:
         return None
 
+    allowed_roles = {"Author", "Editor", "Reviewer", "Translator"}
     con = [
         c
         for c in dig(obj, "contributors", [])
-        if c.get("contributorRoles", None) == ["Author"]
-        or c.get("contributorRoles", None) == ["Editor"]
+        if set(c.get("contributorRoles", [])) & allowed_roles
     ]
 
     person_names = []
@@ -718,13 +723,15 @@ def get_contributors(obj) -> dict | None:
     anonymous_contributors = []
 
     for num, contributor in enumerate(con):
-        contributor_role = (
-            "author" if "Author" in contributor.get("contributorRoles") else None
+        roles = wrap(contributor.get("contributorRoles"))
+        contributor_role = next(
+            (
+                CM_TO_CR_CONTRIBUTOR_ROLES.get(role)
+                for role in roles
+                if role and CM_TO_CR_CONTRIBUTOR_ROLES.get(role)
+            ),
+            "author",
         )
-        if contributor_role is None:
-            contributor_role = (
-                "editor" if "Editor" in contributor.get("contributorRoles") else None
-            )
         sequence = "first" if num == 0 else "additional"
         if (
             contributor.get("type", None) == "Organization"
